@@ -68,6 +68,9 @@
 #include <cc++/common.h>
 
 #include <iostream>
+#ifndef	WIN32
+#include <cstdlib>
+#endif
 
 #ifdef	CCXX_NAMESPACES
 using namespace std;
