@@ -49,7 +49,7 @@ int main(int argc, char *argv[])
  {
    unsigned char test[44];
    unsigned char buf[4];
-   unsigned long crc;
+   uint32 crc;
    int i;
 
    cout << "CRC32 Algorithm Test\n\n";
@@ -65,7 +65,7 @@ int main(int argc, char *argv[])
    CRC32Digest crc1;
    crc1.putDigest(test, 44);
    crc1.getDigest(buf);
-   crc = *(unsigned long *)buf;
+   crc = *(uint32 *)buf;
    cout << "Test #1 CRC32 = " << hex << crc << "\n\n";
    if (crc == 0x864d7f99)
 	  cout << "Test #1 PASSED\n\n\n";
@@ -84,7 +84,7 @@ int main(int argc, char *argv[])
    CRC32Digest crc2;
    crc2.putDigest(test, 44);
    crc2.getDigest(buf);
-   crc = *(unsigned long *)buf;
+   crc = *(uint32 *)buf;
    cout << "Test #2 CRC32 = " << hex << crc << "\n\n";
    if (crc == 0xc55e457a)
 	  cout << "Test #2 PASSED\n\n\n";
@@ -102,7 +102,7 @@ int main(int argc, char *argv[])
    CRC32Digest crc3;
    crc3.putDigest(test, 44);
    crc3.getDigest(buf);
-   crc = *(unsigned long *)buf;
+   crc = *(uint32 *)buf;
    cout << "Test #3 CRC32 = " << hex << crc << "\n\n";
    if (crc == 0xbf671ed0)
 	  cout << "Test #3 PASSED\n\n\n";
