@@ -24,6 +24,9 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "serialecho.h"
+#ifndef	WIN32
+#include <cstdlib>
+#endif
 
 using namespace std;
 
