@@ -1,27 +1,28 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -85,13 +86,12 @@ DSO::~DSO()
 		return;
 
 	sym = NSLookupSymbolInModule(oModule, "__fini");
-	if(sym != NULL)
-	{
+	if(sym != NULL) {
 		fini = (void (*)(void))NSAddressOfSymbol(sym);
 		fini();
 	}
 
-	NSUnLinkModule(oModule, NSUNLINKMODULE_OPTION_NONE);		
+	NSUnLinkModule(oModule, NSUNLINKMODULE_OPTION_NONE);
 #elif defined(HAVE_SHL_LOAD)
 	if(image)
 		shl_unload(image);
@@ -111,7 +111,7 @@ DSO::~DSO()
 
 	if(next)
 		next->prev = prev;
-	
+
 	if(first == this)
 		first = next;
 	if(last == this)
@@ -143,8 +143,7 @@ void DSO::loader(const char *filename, bool flag)
 
 	fprintf(stderr, "**** HERE %s\n", filename);
 
-	switch(NSCreateObjectFileImageFromFile(filename, &oImage)) 
-	{
+	switch(NSCreateObjectFileImageFromFile(filename, &oImage)) {
 	case NSObjectFileImageSuccess:
 		break;
 	default:
@@ -154,12 +153,11 @@ void DSO::loader(const char *filename, bool flag)
 	if(flag)
 		oModule = NSLinkModule(oImage, filename, NSLINKMODULE_OPTION_BINDNOW | NSLINKMODULE_OPTION_RETURN_ON_ERROR);
 	else
-		oModule = NSLinkModule(oImage, filename, NSLINKMODULE_OPTION_RETURN_ON_ERROR); 
+		oModule = NSLinkModule(oImage, filename, NSLINKMODULE_OPTION_RETURN_ON_ERROR);
 	NSDestroyObjectFileImage(oImage);
 	if(oModule != NULL)
 		sym = NSLookupSymbolInModule(oModule, "__init");
-	if(sym)
-	{
+	if(sym) {
 		init = (void (*)(void))NSAddressOfSymbol(sym);
 		init();
 	}
@@ -169,7 +167,7 @@ void DSO::loader(const char *filename, bool flag)
 	if(flag)
 		image = shl_load(filename, BIND_IMMEDIATE, 0L);
 	else
-		image = shl_load(filename, BIND_DEFERRED, 0L); 
+		image = shl_load(filename, BIND_DEFERRED, 0L);
 #else
 	if(flag)
 		image = dlopen(filename, RTLD_NOW | RTLD_GLOBAL);
@@ -179,20 +177,16 @@ void DSO::loader(const char *filename, bool flag)
 #endif
 
 #if defined(WIN32)
-	if(!hImage)
-	{
+	if(!hImage) {
 		err = "load failed";
 #elif defined(HAVE_MACH_DYLD)
-	if(oModule == NULL)
-	{
+	if(oModule == NULL) {
 		err = "load failed";
 #elif defined(HAVE_SHL_LOAD)
-	if(!image)
-	{
+	if(!image) {
 		err = "load failed";
 #else
-	if(!image)
-	{
+	if(!image) {
 		err = dlerror();
 #endif
 
@@ -213,8 +207,7 @@ void DSO::loader(const char *filename, bool flag)
 		return;
 	}
 
-	if(!last)
-	{
+	if(!last) {
 		last = first = this;
 		return;
 	}
@@ -224,7 +217,7 @@ void DSO::loader(const char *filename, bool flag)
 	prev = last;
 	last = this;
 	mutex.leaveMutex();
-}	
+			}
 
 DSO *DSO::getObject(const char *id)
 {
@@ -238,16 +231,15 @@ DSO *DSO::getObject(const char *id)
 
 	mutex.enterMutex();
 	dso = first;
-	while(dso)
-	{
+	while(dso) {
 		if(!stricmp(dso->id, chk))
 			break;
 		dso = dso->next;
 	}
 	mutex.leaveMutex();
 	return dso;
-}
-	
+			}
+
 bool DSO::isValid(void)
 {
 #if	defined(WIN32)
@@ -260,7 +252,7 @@ bool DSO::isValid(void)
 		return false;
 
 	return true;
-}
+			}
 
 void *DSO::operator[](const char *sym)
 {
@@ -287,7 +279,7 @@ void *DSO::operator[](const char *sym)
 #else
 	return dlsym(image, (char *)sym);
 #endif
-}
+			}
 
 #endif
 
@@ -296,38 +288,38 @@ void *DSO::operator[](const char *sym)
 static void MyLinkError(NSLinkEditErrors c, int errorNumber, const char *filename, const char *errstr)
 {
 	slog.error() << "dyld: " << filename << ": " << errstr << std::endl;
-}
+			}
 
 static void MyUndefined(const char *symname)
 {
 	slog.error() << "dyld: undefined: " << symname << std::endl;
-}
+			}
 
 static NSModule MyMultiple(NSSymbol s, NSModule oMod, NSModule nMod)
 {
 	slog.error() << "dyld: multiply defined symbols" << std::endl;
-}
+			}
 
 void DSO::setDebug(void)
 {
 	static NSLinkEditErrorHandlers handlers = {
-		&MyUndefined, 
-		&MyMultiple, 
+		&MyUndefined,
+		&MyMultiple,
 		&MyLinkError};
 
 	NSInstallLinkEditErrorHandlers(&handlers);
-}
+			}
 
 #else
 
 void DSO::setDebug(void)
 {
-}
+			}
 
 #endif
 
 #ifdef	CCXX_NAMESPACES
-}
+		}
 #endif
 
 
