@@ -1,27 +1,28 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -59,10 +60,9 @@ ThreadLock::ThreadLock()
 {
 #ifdef HAVE_PTHREAD_RWLOCK
 	pthread_rwlockattr_t attr;
-	
+
 	pthread_rwlockattr_init(&attr);
-	if(pthread_rwlock_init(&_lock, &attr))
-	{
+	if(pthread_rwlock_init(&_lock, &attr)) {
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject)
 			throw(this);
@@ -132,7 +132,7 @@ bool ThreadLock::tryWriteLock(void)
 }
 
 #ifndef WIN32
-Conditional::Conditional(const char *id) 
+Conditional::Conditional(const char *id)
 {
 	pthread_mutexattr_t attr;
 	pthread_mutexattr_init(&attr);
@@ -150,19 +150,19 @@ Conditional::~Conditional()
 
 bool Conditional::tryEnterMutex(void)
 {
-        if(pthread_mutex_trylock(&_mutex) != 0)
+	if(pthread_mutex_trylock(&_mutex) != 0)
 		return false;
 	return true;
 }
 
 void Conditional::enterMutex(void)
 {
-        pthread_mutex_lock(&_mutex);
+	pthread_mutex_lock(&_mutex);
 }
 
 void Conditional::leaveMutex(void)
 {
-        pthread_mutex_unlock(&_mutex);
+	pthread_mutex_unlock(&_mutex);
 }
 
 void Conditional::signal(bool broadcast)
@@ -180,8 +180,7 @@ bool Conditional::wait(timeout_t timeout, bool locked)
 
 	if(!locked)
 		enterMutex();
-	if(!timeout)
-	{
+	if(!timeout) {
 		pthread_cond_wait(&_cond, &_mutex);
 		if(!locked)
 			leaveMutex();
@@ -232,7 +231,7 @@ bool Mutex::tryEnterMutex(void)
 void Mutex::enterMutex(void)
 {
 	if(_debug && _name)
-		slog.debug() << Thread::get()->getName() 
+		slog.debug() << Thread::get()->getName()
 			<< ": entering " << _name << std::endl;
 
 	pthread_mutex_lock(&_mutex);
@@ -242,7 +241,7 @@ void Mutex::leaveMutex(void)
 {
 	pthread_mutex_unlock(&_mutex);
 	if(_debug && _name)
-		slog.debug() << Thread::get()->getName() 
+		slog.debug() << Thread::get()->getName()
 			<< ": leaving" << _name << std::endl;
 
 }
@@ -251,8 +250,7 @@ void Mutex::leaveMutex(void)
 
 void Mutex::enterMutex(void)
 {
-	if(_tid == Thread::get())
-	{
+	if(_tid == Thread::get()) {
 		++_level;
 		return;
 	}
@@ -273,14 +271,13 @@ void Mutex::leaveMutex(void)
 	_tid = NULL;
 	_level = 0;
 	pthread_mutex_unlock(&_mutex);
-    if(_debug && _name)
+	if(_debug && _name)
 		std::cerr << Thread::get()->getName() << ": leaving" << _name << std::endl;
 }
 
 bool Mutex::tryEnterMutex(void)
 {
-	if(_tid == Thread::get())
-	{
+	if(_tid == Thread::get()) {
 		++_level;
 		return true;
 	}
@@ -295,25 +292,24 @@ bool Mutex::tryEnterMutex(void)
 #else // WIN32
 
 Mutex::Mutex(const char *name)
-#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX 
+#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX
 	:_mutex(0)
 #endif // MUTEX_UNDERGROUND_WIN32_MUTEX
 {
-#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION 
+#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 #if _WIN32_WINNT >= 0x0403
-	if(!InitializeCriticalSectionAndSpinCount(&_criticalSection, 4000))
-	{
+	if(!InitializeCriticalSectionAndSpinCount(&_criticalSection, 4000)) {
 		THROW(this);
 	}
 #elif _WIN32_WINNT >= 0x0400
 	// can rise STATUS_NO_MEMORY exception in low memory situations.
-	InitializeCriticalSection(&_criticalSection); 
+	InitializeCriticalSection(&_criticalSection);
 #else
 #error "Not supported Windows version"
 #endif
 #endif // MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX 
+#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX
 	_mutex = ::CreateMutex(NULL,FALSE,NULL);
 	if(!_mutex)
 		THROW(this);
@@ -326,14 +322,14 @@ Mutex::Mutex(const char *name)
 void Mutex::enterMutex(void)
 {
 	if(_debug && _name)
-		slog.debug() << Thread::get()->getName() 
+		slog.debug() << Thread::get()->getName()
 			<< ": entering " << _name << std::endl;
 
-#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION 
+#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 	::EnterCriticalSection(&_criticalSection);
 #endif // MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX 
+#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX
 	Thread::waitThread(_mutex, INFINITE);
 #endif // MUTEX_UNDERGROUND_WIN32_MUTEX
 
@@ -341,7 +337,7 @@ void Mutex::enterMutex(void)
 
 bool Mutex::tryEnterMutex(void)
 {
-#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION 
+#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 	return (::TryEnterCriticalSection(&_criticalSection) == TRUE);
 #endif // MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
@@ -352,29 +348,29 @@ bool Mutex::tryEnterMutex(void)
 
 Mutex::~Mutex()
 {
-#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION 
+#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 	::DeleteCriticalSection(&_criticalSection);
 #endif // MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX 
+#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX
 	::CloseHandle(_mutex);
 #endif // MUTEX_UNDERGROUND_WIN32_MUTEX
 
 }
-	
+
 void Mutex::leaveMutex(void)
 {
-#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION 
+#ifdef MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 	::LeaveCriticalSection(&_criticalSection);
 #endif // MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX 
+#ifdef MUTEX_UNDERGROUND_WIN32_MUTEX
 	if (!ReleaseMutex(_mutex))
 		THROW(this);
 #endif // MUTEX_UNDERGROUND_WIN32_MUTEX
 
 	if(_debug && _name)
-		slog.debug() << Thread::get()->getName() 
+		slog.debug() << Thread::get()->getName()
 			<< ": leaving" << _name << std::endl;
 }
 #endif	// WIN32 MUTEX
@@ -407,11 +403,9 @@ int operator--(MutexCounter &mc)
 	int rtn = 0;
 
 	mc.enterMutex();
-	if(mc.counter)
-	{
+	if(mc.counter) {
 		rtn = --mc.counter;
-		if(!rtn)
-		{
+		if(!rtn) {
 			mc.leaveMutex();
 			THROW(mc);
 		}
@@ -425,7 +419,7 @@ int operator--(MutexCounter &mc)
 AtomicCounter::AtomicCounter()
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	counter = 0;
 #else
 	atomic.counter = 0;
@@ -435,7 +429,7 @@ AtomicCounter::AtomicCounter()
 AtomicCounter::AtomicCounter(int value)
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	counter = 0;
 #else
 	atomic.counter = value;
@@ -516,7 +510,7 @@ int AtomicCounter::operator-=(int change)
 int AtomicCounter::operator+(int change)
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	return counter + change;
 #else
 	return atomic_read(&atomic) + change;
@@ -526,7 +520,7 @@ int AtomicCounter::operator+(int change)
 int AtomicCounter::operator-(int change)
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	return counter - change;
 #else
 	return atomic_read(&atomic) - change;
@@ -536,7 +530,7 @@ int AtomicCounter::operator-(int change)
 int AtomicCounter::operator=(int value)
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	return counter = value;
 #else
 	atomic_set(&atomic, value);
@@ -547,7 +541,7 @@ int AtomicCounter::operator=(int value)
 bool AtomicCounter::operator!(void)
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	int value = counter;
 #else
 	int value = atomic_read(&atomic);
@@ -560,7 +554,7 @@ bool AtomicCounter::operator!(void)
 AtomicCounter::operator int()
 {
 #if     defined(HAVE_ATOMIC_AIX) || defined(HAVE_GCC_BITS_ATOMIC) \
-    || defined(HAVE_GCC_CXX_BITS_ATOMIC)
+	|| defined(HAVE_GCC_CXX_BITS_ATOMIC)
 	return counter;
 #else
 	return atomic_read(&atomic);
@@ -573,25 +567,25 @@ AtomicCounter::AtomicCounter()
 {
 	counter = 0;
 
-        pthread_mutexattr_t _attr;
-        pthread_mutexattr_init(&_attr);
-        pthread_mutex_init(&_mutex, &_attr);
-        pthread_mutexattr_destroy(&_attr);
+	pthread_mutexattr_t _attr;
+	pthread_mutexattr_init(&_attr);
+	pthread_mutex_init(&_mutex, &_attr);
+	pthread_mutexattr_destroy(&_attr);
 }
 
 AtomicCounter::AtomicCounter(int value)
 {
 	counter = value;
-	
-        pthread_mutexattr_t _attr;
-        pthread_mutexattr_init(&_attr);
-        pthread_mutex_init(&_mutex, &_attr);
-        pthread_mutexattr_destroy(&_attr);
+
+	pthread_mutexattr_t _attr;
+	pthread_mutexattr_init(&_attr);
+	pthread_mutex_init(&_mutex, &_attr);
+	pthread_mutexattr_destroy(&_attr);
 }
 
 AtomicCounter::~AtomicCounter()
 {
-        pthread_mutex_destroy(&_mutex);
+	pthread_mutex_destroy(&_mutex);
 }
 
 int AtomicCounter::operator++(void)
@@ -687,7 +681,7 @@ int AtomicCounter::operator+=(int change)
 	// FIXME: enhance with InterlockExchangeAdd
 	while(--change>=0)
 		InterlockedIncrement(&atomic);
-	
+
 	return atomic;
 }
 
