@@ -1,4 +1,5 @@
 // Copyright (C) 2004-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,11 +46,11 @@
 namespace ost {
 #endif
 
-RefObject::~RefObject() {};
+RefObject::~RefObject() {}
 
-void RefPointer::enterLock(void) {};
+void RefPointer::enterLock(void) {}
 
-void RefPointer::leaveLock(void) {};
+void RefPointer::leaveLock(void) {}
 
 void RefPointer::detach(void)
 {
