@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -562,7 +563,7 @@ Socket::Error Socket::connectError(void)
 }
 #endif
 
-Socket::Error Socket::error(Error err, char *errs, long systemError) const
+Socket::Error Socket::error(Error err, const char *errs, long systemError) const
 {
 	errid  = err;
 	errstr = errs;
@@ -1149,7 +1150,7 @@ Socket::Error Socket::join(const IPV4Multicast &ia)
 		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
-	memcpy(&group.imr_interface, &myaddr.sin_addr, sizeof(&myaddr.sin_addr));
+	group.imr_interface.s_addr = INADDR_ANY;
 	group.imr_multiaddr = getaddress(ia);
 	setsockopt(so, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
@@ -1170,7 +1171,7 @@ Socket::Error Socket::join(const IPV6Multicast &ia)
 		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
-	memcpy(&group.ipv6mr_interface, &myaddr.sin6_addr, sizeof(&myaddr.sin6_addr));
+	group.ipv6mr_interface = 0;
 	group.ipv6mr_multiaddr = getaddress(ia);
 	setsockopt(so, IPPROTO_IPV6, IPV6_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
@@ -1192,7 +1193,7 @@ Socket::Error Socket::drop(const IPV4Multicast &ia)
 		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
-	memcpy(&group.imr_interface, &myaddr.sin_addr, sizeof(&myaddr.sin_addr));
+	group.imr_interface.s_addr = INADDR_ANY;
 	group.imr_multiaddr = getaddress(ia);
 	setsockopt(so, IPPROTO_IP, IP_DROP_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
@@ -1213,7 +1214,7 @@ Socket::Error Socket::drop(const IPV6Multicast &ia)
 		return error(errMulticastDisabled,(char *)"Multicast not enabled on socket");
 
 	getsockname(so, (struct sockaddr *)&myaddr, &len);
-	memcpy(&group.ipv6mr_interface, &myaddr.sin6_addr, sizeof(&myaddr.sin6_addr));
+	group.ipv6mr_interface = 0;
 	group.ipv6mr_multiaddr = getaddress(ia);
 	setsockopt(so, IPPROTO_IPV6, IPV6_DROP_MEMBERSHIP, (char *)&group, sizeof(group));
 	return errSuccess;
@@ -3123,9 +3124,8 @@ Thread(pri, stack), TCPStream(s)
 
 TCPSession::~TCPSession()
 {
-	terminate();
 	endStream();
-					}
+}
 
 int TCPSession::waitConnection(timeout_t timer)
 {
