@@ -9,20 +9,18 @@ using namespace ost;
 #endif
 
 // Test child thread destroying before father
-// 
+//
 class Child: public Thread
 {
 public:
 	Child()
 	{ }
-	void run()
-	{
+	void run() {
 		cout << "child start" << endl;
 		Thread::sleep(3000);
 		cout << "child end" << endl;
 	}
-	void final()
-	{
+	void final() {
 //		delete this;
 	}
 };
@@ -32,16 +30,14 @@ class Father: public Thread
 public:
 	Father()
 	{ }
-	void run()
-	{
+	void run() {
 		cout << "starting child thread" << endl;
 		Thread *th = new Child();
 		th->detach();
 		Thread::sleep(1000);
 		cout << "father end" << endl;
 	}
-	void final()
-	{
+	void final() {
 		// delete this; - not used since detached threads self delete
 		// reset memory to test access violation
 		memset(this,0,sizeof(*this));
